Roadmap
=======

Next up
^^^^^^^
* Include clean, indexed dictionary in package.

Wishlist
^^^^^^^^
* Depend on ``attr`` module instead of ``namedtuple``.

Improvements to automation
^^^^^^^^^^^^^^^^^^^^^^^^^^
* get coverage automation through travis.
* cherrypick tweaks to template out to separate ``package-automation`` branch
* Port ``package-automation`` into a ``cookiecutter-pypackage`` fork.
/
